core/animations/animations library

Animation widgets. Import: core/animations/animations.dart

Classes

FadeIn
A widget that animates its child with a fade-in effect.
ScaleIn
A widget that animates its child with a scale (pop-in) effect.
SlideIn
A widget that animates its child with a slide-in effect.

Extensions

DurationExtension on int
Extension for concise duration literals.