Env class

Current environment. Set via --dart-define=ENV=dev|staging|prod

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current AppEnv
no setter
isDev bool
no setter
isProd bool
no setter
isStaging bool
no setter