ApiClient class
REST API client. Dio + interceptors + centralized error handling. Use for hybrid apps (Firebase + REST).
Properties
- dio → Dio
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete<
T> (String path, {dynamic data, Map< String, dynamic> ? queryParameters, Options? options}) → Future<Response< T> > -
get<
T> (String path, {Map< String, dynamic> ? queryParameters, Options? options}) → Future<Response< T> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post<
T> (String path, {dynamic data, Map< String, dynamic> ? queryParameters, Options? options}) → Future<Response< T> > -
put<
T> (String path, {dynamic data, Map< String, dynamic> ? queryParameters, Options? options}) → Future<Response< T> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited