FirebaseAuthService class

Firebase Auth wrapper. Use from datasources, not from UI.

Constructors

FirebaseAuthService()

Properties

authStateChanges Stream<User?>
no setter
currentUser → User?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createUserWithEmailAndPassword(String email, String password) Future<UserCredential?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendPasswordResetEmail(String email) Future<void>
signInWithEmailAndPassword(String email, String password) Future<UserCredential?>
signOut() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited