AuthRepositoryImpl class

Auth repository implementation. Delegates to datasource.

Implemented types

Constructors

AuthRepositoryImpl(AuthDatasource _datasource)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

login(String email, String password) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendPasswordReset(String email) Future<void>
override
signOut() Future<void>
override
signUp(String email, String password) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited