ProfileEntity class

Profile entity (domain layer). Pure Dart, no frameworks.

Constructors

ProfileEntity({required String id, required String displayName, String? email, String? avatarUrl})
const

Properties

avatarUrl String?
final
displayName String
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited