Spacing class

Spacing design tokens for consistent layout.

Constructors

Spacing()

Properties

hashCode int
The hash code for this object.
no setterinherited
lg double
Large: 24px.
no setter
md double
Medium: 16px.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
Small: 8px.
no setter
xl double
Extra large: 32px.
no setter
xs double
Extra small: 4px.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited