menu
modularapparchitecture package
documentation
core/animations/animations.dart
core/animations/animations.dart
dark_mode
light_mode
core/animations/animations
library
Animation widgets. Import: core/animations/animations.dart
Classes
FadeIn
A widget that animates its child with a fade-in effect.
ScaleIn
A widget that animates its child with a scale (pop-in) effect.
SlideIn
A widget that animates its child with a slide-in effect.
Extensions
DurationExtension
on
int
Extension for concise duration literals.
modularapparchitecture package
documentation
core/animations/animations.dart
modularapparchitecture
package
Libraries
core/animations/animations
core/animations/fade_in
core/animations/scale_in
core/animations/slide_in
core/config/env
core/di/app_bindings
core/routes/app_routes
core/services/api_client
core/services/firebase_auth_service
core/services/firestore_service
core/theme/app_colors
core/theme/app_theme
core/theme/app_typography
features/auth/bindings/auth_binding
features/auth/data/datasources/auth_datasource
features/auth/data/repositories/auth_repository_impl
features/auth/domain/repositories/auth_repository
features/auth/domain/usecases/login_usecase
features/auth/domain/usecases/signup_usecase
features/auth/presentation/controllers/auth_controller
features/auth/presentation/pages/login_page
features/auth/presentation/pages/signup_page
features/auth/presentation/pages/splash_page
features/demo/bindings/demo_binding
features/home/presentation/pages/home_page
features/profile/bindings/profile_binding
features/profile/data/datasources/profile_datasource
features/profile/data/datasources/profile_datasource_impl
features/profile/data/repositories/profile_repository_impl
features/profile/domain/entities/profile_entity
features/profile/domain/repositories/profile_repository
features/profile/domain/usecases/get_profile_usecase
features/profile/domain/usecases/update_profile_usecase
features/profile/presentation/controllers/profile_controller
features/profile/presentation/pages/profile_page
main
modularapparchitecture
shared/extensions/theme_extensions
animations library