FirestoreService class
Firestore wrapper. Use from repositories/datasources.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collection(
String path) → CollectionReference< Map< String, dynamic> > -
docStream(
String path) → Stream< DocumentSnapshot< Map< >String, dynamic> > -
getDoc(
String path) → Future< DocumentSnapshot< Map< >String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDoc(
String path, Map< String, dynamic> data, {bool merge = false}) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited